summaryrefslogtreecommitdiffstats
path: root/src/mbedTLS++/EntropyContext.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/mbedTLS++/EntropyContext.h (renamed from src/PolarSSL++/EntropyContext.h)8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/PolarSSL++/EntropyContext.h b/src/mbedTLS++/EntropyContext.h
index 69671d32f..37b6f120e 100644
--- a/src/PolarSSL++/EntropyContext.h
+++ b/src/mbedTLS++/EntropyContext.h
@@ -1,7 +1,7 @@
-
+
// EntropyContext.h
// Declares the cEntropyContext class representing a wrapper over entropy contexts in PolarSSL
@@ -9,7 +9,7 @@
#pragma once
-#include "polarssl/entropy.h"
+#include "mbedtls/entropy.h"
@@ -23,7 +23,7 @@ public:
~cEntropyContext();
protected:
- entropy_context m_Entropy;
+ mbedtls_entropy_context m_Entropy;
} ;
@@ -1,7 +1,7 @@
// EntropyContext.h
-// Declares the cEntropyContext class representing a wrapper over entropy contexts in PolarSSL
+// Declares the cEntropyContext class representing a wrapper over entropy contexts in mbedTLS
#pragma once